pub struct SomeMut<'a, T>(_);
Converts this type into a mutable reference of the (usually inferred) input type.
Converts this type into a shared reference of the (usually inferred) input type.
Immutably borrows from an owned value.
Read more
Formats the value using the given formatter.
Read more
The resulting type after dereferencing.
Dereferences the value.
Mutably dereferences the value.
Formats the value using the given formatter.
Read more
This method tests for self and other values to be equal, and is used
by ==.
This method tests for !=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more
This method tests less than (for
self and
other) and is used by the
< operator.
Read more
This method tests less than or equal to (for
self and
other) and is used by the
<=
operator.
Read more
This method tests greater than (for
self and
other) and is used by the
> operator.
Read more
This method tests greater than or equal to (for
self and
other) and is used by the
>=
operator.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.